@@ -1,3 +1,4 @@
+"""Metadata about curret installed binary"""
 import subprocess
 import re
 from .config import get_config as C
@@ -8,7 +9,7 @@ def installed_version():
     if not C().firefox_binary.is_file():
         return 0
     infos = subprocess.run([C().firefox_binary, '--version'], capture_output=True, check=True)
-    match = re.search(r'\d+\.\d+\.\d+', infos.stdout.decode())
+    match = re.search(r'\d+\.\d+', infos.stdout.decode())
     if match:
         return match.group()
     return None
